@@ -25,31 +25,6 @@
 
 
 #if 1 // FIXME! it's ad-hoc.
-extern ConvRule ja_romakana_table[];
-extern ConvRule ja_kana_table[];
-
-extern ConvRule romakana_ja_period_rule[];
-extern ConvRule romakana_wide_latin_period_rule[];
-extern ConvRule romakana_latin_period_rule[];
-
-extern ConvRule romakana_ja_comma_rule[];
-extern ConvRule romakana_wide_latin_comma_rule[];
-extern ConvRule romakana_latin_comma_rule[];
-
-extern ConvRule kana_ja_period_rule[];
-extern ConvRule kana_wide_latin_period_rule[];
-extern ConvRule kana_latin_period_rule[];
-
-extern ConvRule kana_ja_comma_rule[];
-extern ConvRule kana_wide_latin_comma_rule[];
-extern ConvRule kana_latin_comma_rule[];
-
-extern ConvRule wide_space_rule[];
-extern ConvRule space_rule[];
-
-extern HiraganaKatakanaRule ja_hiragana_katakana_table[];
-extern WideRule             ja_wide_table[];
-
 static void      convert_string_to_wide       (const String     &str,
                                                WideString       &wide,
                                                SpaceType         space);;
@@ -64,24 +39,27 @@ static ConvRule *get_comma_rule               (TypingMethod      method,
 
 
 
-PreeditChar::PreeditChar (void)
+AnthyPreeditChar::AnthyPreeditChar (void)
     : pending (true)
 {
 }
 
-PreeditChar::~PreeditChar ()
+AnthyPreeditChar::~AnthyPreeditChar ()
 {
 }
 
 
 
-Preedit::Preedit ()
+AnthyPreedit::AnthyPreedit ()
     : m_anthy_context (anthy_create_context()),
+      m_romaji_half_symbol (false),
+      m_romaji_half_number (false),
       m_input_mode (MODE_HIRAGANA),
       m_typing_method (METHOD_ROMAKANA),
       m_period_style (PERIOD_JAPANESE),
       m_comma_style (COMMA_JAPANESE),
       m_space_type (SPACE_WIDE),
+      m_ten_key_type (TEN_KEY_WIDE),
       m_auto_convert (false),
       m_start_char (0),
       m_char_caret (0),
@@ -99,10 +77,11 @@ Preedit::Preedit ()
     if (!m_iconv.set_encoding ("EUC-JP"))
         return;
 
-    set_table (m_typing_method, m_period_style, m_comma_style, m_space_type);
+    set_table (m_romaji_half_symbol, m_romaji_half_number,
+               m_typing_method, m_period_style, m_comma_style, m_space_type);
 }
 
-Preedit::~Preedit ()
+AnthyPreedit::~AnthyPreedit ()
 {
     anthy_release_context (m_anthy_context);
 }
@@ -112,7 +91,7 @@ Preedit::~Preedit ()
  * getting status
  */
 unsigned int
-Preedit::get_length (PreeditStringType type)
+AnthyPreedit::get_length (AnthyPreeditStringType type)
 {
     if (type == PREEDIT_CURRENT) {
         if (is_converting ())
@@ -151,7 +130,7 @@ Preedit::get_length (PreeditStringType type)
 }
 
 WideString
-Preedit::get_string (PreeditStringType type)
+AnthyPreedit::get_string (AnthyPreeditStringType type)
 {
     if (type == PREEDIT_CURRENT) {
         if (is_converting ())
@@ -184,7 +163,7 @@ Preedit::get_string (PreeditStringType type)
 }
 
 unsigned int
-Preedit::get_preedit_length (void)
+AnthyPreedit::get_preedit_length (void)
 {
     unsigned int len = 0;
     for (unsigned int i = 0; i < m_char_list.size (); i++)
@@ -193,7 +172,7 @@ Preedit::get_preedit_length (void)
 }
 
 WideString
-Preedit::get_preedit_string_as_hiragana (void)
+AnthyPreedit::get_preedit_string_as_hiragana (void)
 {
     WideString widestr;
     unsigned int len = 0;
@@ -204,7 +183,7 @@ Preedit::get_preedit_string_as_hiragana (void)
 }
 
 WideString
-Preedit::get_preedit_string (void)
+AnthyPreedit::get_preedit_string (void)
 {
     WideString tmpwidestr, widestr;
     String str;
@@ -235,14 +214,14 @@ Preedit::get_preedit_string (void)
 }
 
 AttributeList
-Preedit::get_attribute_list (PreeditStringType type)
+AnthyPreedit::get_attribute_list (AnthyPreeditStringType type)
 {
     /* FIXME! */
     return m_conv_attrs;
 }
 
 bool
-Preedit::is_preediting (void)
+AnthyPreedit::is_preediting (void)
 {
     if (m_char_list.size () <= 0)
         return false;
@@ -251,7 +230,7 @@ Preedit::is_preediting (void)
 }
 
 bool
-Preedit::is_converting (void)
+AnthyPreedit::is_converting (void)
 {
     if (m_conv_string.length () > 0)
         return true;
@@ -260,7 +239,7 @@ Preedit::is_converting (void)
 }
 
 bool
-Preedit::is_kana_converting (void)
+AnthyPreedit::is_kana_converting (void)
 {
     return m_kana_converting;
 }
@@ -270,20 +249,111 @@ Preedit::is_kana_converting (void)
  * manipulating the preedit string
  */
 bool
-Preedit::append (const KeyEvent & key)
+AnthyPreedit::can_process (const KeyEvent & key)
 {
-    if (!isprint(key.get_ascii_code ()))
-        return false;
+    if (isprint(key.get_ascii_code ()) && !isspace(key.get_ascii_code ()))
+        return true;
 
-    char str[2];
-    str[0] = key.code;
-    str[1] = '\0';
+    if (key.code >= SCIM_KEY_KP_0 && key.code <= SCIM_KEY_KP_9)
+        return true;
 
-    return append_str (String (str));
+    if (key.code >= SCIM_KEY_KP_Multiply && key.code <= SCIM_KEY_KP_Divide)
+        return true;
+
+    if (key.code == SCIM_KEY_KP_Equal)
+        return true;
+
+    return false;
 }
 
 bool
-Preedit::append_str (const String & str)
+AnthyPreedit::append (const KeyEvent & key)
+{
+    bool is_ten_key = true;
+
+    if (!can_process (key))
+        return false;
+
+    char str[2];
+
+    switch (key.code) {
+    case SCIM_KEY_KP_Equal:
+        str[0] = '=';
+        break;
+
+    case SCIM_KEY_KP_Multiply:
+        str[0] = '*';
+        break;
+
+    case SCIM_KEY_KP_Add:
+        str[0] = '+';
+        break;
+
+    case SCIM_KEY_KP_Separator:
+        str[0] = ',';
+        break;
+
+    case SCIM_KEY_KP_Subtract:
+        str[0] = '-';
+        break;
+
+    case SCIM_KEY_KP_Decimal:
+        str[0] = '.';
+        break;
+
+    case SCIM_KEY_KP_Divide:
+        str[0] = '/';
+        break;
+
+    case SCIM_KEY_KP_0:
+    case SCIM_KEY_KP_1:
+    case SCIM_KEY_KP_2:
+    case SCIM_KEY_KP_3:
+    case SCIM_KEY_KP_4:
+    case SCIM_KEY_KP_5:
+    case SCIM_KEY_KP_6:
+    case SCIM_KEY_KP_7:
+    case SCIM_KEY_KP_8:
+    case SCIM_KEY_KP_9:
+        str[0] = '0' + key.code - SCIM_KEY_KP_0;
+        break;
+
+    default:
+        is_ten_key = false;
+        str[0] = key.code;
+        break;
+    }
+
+    str[1] = '\0';
+
+    bool half = true;
+    bool prev_symbol = m_romaji_half_symbol;
+    bool prev_number = m_romaji_half_number;
+
+    if (is_ten_key && m_ten_key_type != TEN_KEY_FOLLOW_MODE) {
+        if (m_ten_key_type == TEN_KEY_HALF)
+            half = true;
+        else if (m_ten_key_type == TEN_KEY_WIDE)
+            half = false;
+
+        set_table (half, half,
+                   m_typing_method, m_period_style,
+                   m_comma_style, m_space_type);
+    }
+
+    bool retval = append_str (String (str));
+
+    if (is_ten_key && m_ten_key_type != TEN_KEY_FOLLOW_MODE) {
+        set_table (prev_symbol, prev_number,
+                   m_typing_method, m_period_style,
+                   m_comma_style, m_space_type);
+    }
+
+    return retval;
+}
+
+bool
+AnthyPreedit::append_str (const String & str)
 {
     if (str.length () <= 0)
         return false;
@@ -300,13 +370,13 @@ Preedit::append_str (const String & str)
     bool commit_pending;
     commit_pending = m_key2kana.append (str, result, pending);
 
-    std::vector<PreeditChar>::iterator begin = m_char_list.begin ();
+    std::vector<AnthyPreeditChar>::iterator begin = m_char_list.begin ();
 
     if (commit_pending)
         m_char_list[m_char_caret - 1].pending = true;
 
     if (!was_pending || commit_pending) {
-        PreeditChar c;
+        AnthyPreeditChar c;
         m_char_list.insert (begin + m_char_caret, c);
         m_char_caret++;
     }
@@ -319,7 +389,7 @@ Preedit::append_str (const String & str)
         m_char_list[m_char_caret - 1].kana = result;
         m_char_list[m_char_caret - 1].pending = false; // FIXME!
 
-        PreeditChar c;
+        AnthyPreeditChar c;
         c.key += str;
         c.kana = pending;
         c.pending = true;
@@ -352,14 +422,17 @@ Preedit::append_str (const String & str)
         return true;
 #endif
 
-    if (is_comma_or_period (m_char_list[m_char_caret - 1].key) && m_auto_convert)
+    if (is_comma_or_period (m_char_list[m_char_caret - 1].key) &&
+        m_auto_convert)
+    {
         convert ();
+    }
 
     return false;
 }
 
 void
-Preedit::erase (bool backward)
+AnthyPreedit::erase (bool backward)
 {
     if (m_char_list.size () <= 0)
         return;
@@ -382,15 +455,16 @@ Preedit::erase (bool backward)
             WideString kana_str = m_char_list[m_char_caret - 1].kana.substr (0, kana_len - 1);
             m_char_list[m_char_caret - 1].kana = kana_str;
         } else {
-            std::vector<PreeditChar>::iterator end = m_char_list.begin () + m_char_caret;
-            std::vector<PreeditChar>::iterator begin = end - 1;
+            std::vector<AnthyPreeditChar>::iterator end = m_char_list.begin () + m_char_caret;
+            std::vector<AnthyPreeditChar>::iterator begin = end - 1;
             m_char_list.erase(begin, end);
             m_char_caret--;
         }
 
     } else if (!backward && m_char_caret < m_char_list.size ()) {
-        std::vector<PreeditChar>::iterator begin = m_char_list.begin () + m_char_caret;
-        std::vector<PreeditChar>::iterator end = begin + 1;
+        std::vector<AnthyPreeditChar>::iterator begin, end;
+        begin = m_char_list.begin () + m_char_caret;
+        end   = begin + 1;
         m_char_list.erase(begin, end);
     }
 
@@ -409,7 +483,7 @@ Preedit::erase (bool backward)
 }
 
 void
-Preedit::flush_pending (void)
+AnthyPreedit::flush_pending (void)
 {
     if (!m_key2kana.is_pending ()) return;
 
@@ -424,7 +498,7 @@ Preedit::flush_pending (void)
  * manipulating conversion string
  */
 void
-Preedit::create_conversion_string (void)
+AnthyPreedit::create_conversion_string (void)
 {
     m_conv_string.clear ();
     m_conv_attrs.clear ();
@@ -464,9 +538,9 @@ Preedit::create_conversion_string (void)
 }
 
 void
-Preedit::get_kana_substr (WideString & substr,
-                          unsigned int start, unsigned int end,
-                          CandidateType type)
+AnthyPreedit::get_kana_substr (WideString & substr,
+                               unsigned int start, unsigned int end,
+                               CandidateType type)
 {
     unsigned int pos = 0, i = 0;
     WideString kana;
@@ -524,7 +598,7 @@ Preedit::get_kana_substr (WideString & substr,
 }
 
 void
-Preedit::convert (CandidateType type)
+AnthyPreedit::convert (CandidateType type)
 {
     if (type != CANDIDATE_NORMAL) {
         convert_kana (type);
@@ -566,7 +640,7 @@ Preedit::convert (CandidateType type)
 
 #if 1 // FIXME! it's ad-hoc
 void
-Preedit::convert_kana (CandidateType type)
+AnthyPreedit::convert_kana (CandidateType type)
 {
     String str;
     WideString wide;
@@ -587,9 +661,11 @@ Preedit::convert_kana (CandidateType type)
             len += m_char_list[i].kana.length();
 
         if (type == CANDIDATE_LATIN)
-            get_kana_substr (m_conv_string, m_start_segment_pos, len, CANDIDATE_LATIN);
+            get_kana_substr (m_conv_string, m_start_segment_pos, len,
+                             CANDIDATE_LATIN);
         else if (type == CANDIDATE_WIDE_LATIN)
-            get_kana_substr (m_conv_string, m_start_segment_pos, len, CANDIDATE_WIDE_LATIN);
+            get_kana_substr (m_conv_string, m_start_segment_pos, len,
+                             CANDIDATE_WIDE_LATIN);
         break;
     }
     case CANDIDATE_HIRAGANA:
@@ -624,7 +700,7 @@ Preedit::convert_kana (CandidateType type)
 #endif // FIXME!
 
 void
-Preedit::revert (void)
+AnthyPreedit::revert (void)
 {
     m_conv_string.clear ();
     m_conv_attrs.clear ();
@@ -634,21 +710,24 @@ Preedit::revert (void)
 }
 
 void
-Preedit::commit (int segment_id)
+AnthyPreedit::commit (int segment_id, bool learn)
 {
     if (m_kana_converting) return;
     if (m_selected_candidates.size () <= 0) return;
 
     for (unsigned int i = m_start_segment_id;
-         i < m_selected_candidates.size () && (segment_id < 0 || (int) i <= segment_id);
+         i < m_selected_candidates.size () &&
+             (segment_id < 0 || (int) i <= segment_id);
          i++)
     {
-        if (m_selected_candidates[i] >= 0)
+        if (m_selected_candidates[i] >= 0 && learn)
             anthy_commit_segment (m_anthy_context, i, m_selected_candidates[i]);
     }
 
 
-    if (segment_id >= 0 && segment_id + 1 < (int) m_selected_candidates.size ()) {
+    if (segment_id >= 0 &&
+        segment_id + 1 < (int) m_selected_candidates.size ())
+    {
         // remove commited segments
         std::vector<int>::iterator it = m_selected_candidates.begin ();
         m_selected_candidates.erase(it, it + segment_id + 1);
@@ -669,13 +748,16 @@ Preedit::commit (int segment_id)
 
         // recreate conversion string
         create_conversion_string ();
-    } else if (segment_id < 0 || segment_id >= (int) m_selected_candidates.size () - 1) {
+
+    } else if (segment_id < 0 ||
+               segment_id >= (int) m_selected_candidates.size () - 1)
+    {
         clear ();
     }
 }
 
 int
-Preedit::get_nr_segments (void)
+AnthyPreedit::get_nr_segments (void)
 {
     if (!is_converting ()) return 0;
 
@@ -686,7 +768,7 @@ Preedit::get_nr_segments (void)
 }
 
 WideString
-Preedit::get_segment_string (int segment_id)
+AnthyPreedit::get_segment_string (int segment_id)
 {
     if (segment_id < 0)
         segment_id = m_selected_segment_id;
@@ -736,13 +818,13 @@ Preedit::get_segment_string (int segment_id)
 }
 
 int
-Preedit::get_selected_segment (void)
+AnthyPreedit::get_selected_segment (void)
 {
     return m_selected_segment_id;
 }
 
 void
-Preedit::select_segment (int segment_id)
+AnthyPreedit::select_segment (int segment_id)
 {
     if (!is_converting ()) return;
 
@@ -760,7 +842,7 @@ Preedit::select_segment (int segment_id)
 }
 
 int
-Preedit::get_segment_size (int segment_id)
+AnthyPreedit::get_segment_size (int segment_id)
 {
     if (!is_converting ()) return -1;
 
@@ -781,7 +863,7 @@ Preedit::get_segment_size (int segment_id)
 }
 
 void
-Preedit::resize_segment (int relative_size, int segment_id)
+AnthyPreedit::resize_segment (int relative_size, int segment_id)
 {
     if (!is_converting ()) return;
 
@@ -822,7 +904,7 @@ Preedit::resize_segment (int relative_size, int segment_id)
  * candidates for a segment
  */
 void
-Preedit::setup_lookup_table (CommonLookupTable &table, int segment_id)
+AnthyPreedit::setup_lookup_table (CommonLookupTable &table, int segment_id)
 {
     table.clear ();
 
@@ -857,7 +939,7 @@ Preedit::setup_lookup_table (CommonLookupTable &table, int segment_id)
 }
 
 int
-Preedit::get_selected_candidate (int segment_id)
+AnthyPreedit::get_selected_candidate (int segment_id)
 {
     if (!is_converting ()) return -1;
 
@@ -876,7 +958,7 @@ Preedit::get_selected_candidate (int segment_id)
 }
 
 void
-Preedit::select_candidate (int candidate_id, int segment_id)
+AnthyPreedit::select_candidate (int candidate_id, int segment_id)
 {
     if (!is_converting ()) return;
 
@@ -909,7 +991,7 @@ Preedit::select_candidate (int candidate_id, int segment_id)
  * manipulating the caret
  */
 unsigned int
-Preedit::get_caret_pos (void)
+AnthyPreedit::get_caret_pos (void)
 {
     if (is_converting ())
         return m_selected_segment_pos;
@@ -919,7 +1001,7 @@ Preedit::get_caret_pos (void)
 
 // CHECKME!
 void
-Preedit::set_caret_pos (unsigned int pos)
+AnthyPreedit::set_caret_pos (unsigned int pos)
 {
     if (is_converting ())
         return;
@@ -957,7 +1039,7 @@ Preedit::set_caret_pos (unsigned int pos)
 }
 
 void
-Preedit::move_caret (int step)
+AnthyPreedit::move_caret (int step)
 {
     if (is_converting ())
         return;
@@ -986,7 +1068,7 @@ Preedit::move_caret (int step)
 }
 
 void
-Preedit::reset_pending (void)
+AnthyPreedit::reset_pending (void)
 {
     if (m_key2kana.is_pending ())
         m_key2kana.clear ();
@@ -1009,7 +1091,7 @@ Preedit::reset_pending (void)
  * clear all string
  */
 void
-Preedit::clear (void)
+AnthyPreedit::clear (void)
 {
     m_char_list.clear ();
     m_start_char = 0;
@@ -1032,119 +1114,176 @@ Preedit::clear (void)
  * preference
  */
 void
-Preedit::set_input_mode (InputMode mode)
+AnthyPreedit::set_symbol_width (bool half)
+{
+    set_table (half, m_romaji_half_number,
+               m_typing_method, m_period_style, m_comma_style, m_space_type);
+}
+
+bool
+AnthyPreedit::symbol_is_half_width (void)
+{
+    return m_romaji_half_symbol;
+}
+
+void
+AnthyPreedit::set_number_width (bool half)
+{
+    set_table (m_romaji_half_symbol, half,
+               m_typing_method, m_period_style, m_comma_style, m_space_type);
+}
+
+bool
+AnthyPreedit::number_is_half_width (void)
+{
+    return m_romaji_half_symbol;
+}
+
+void
+AnthyPreedit::set_input_mode (InputMode mode)
 {
     m_input_mode = mode;
 }
 
 InputMode
-Preedit::get_input_mode (void)
+AnthyPreedit::get_input_mode (void)
 {
     return m_input_mode;
 }
 
 void
-Preedit::set_typing_method (TypingMethod method)
+AnthyPreedit::set_typing_method (TypingMethod method)
 {
-    set_table (method, m_period_style, m_comma_style, m_space_type);
+    set_table (m_romaji_half_symbol, m_romaji_half_number,
+               method, m_period_style, m_comma_style, m_space_type);
 }
 
 TypingMethod
-Preedit::get_typing_method (void)
+AnthyPreedit::get_typing_method (void)
 {
     return m_typing_method;
 }
 
 void
-Preedit::set_period_style (PeriodStyle style)
+AnthyPreedit::set_period_style (PeriodStyle style)
 {
-    set_table (m_typing_method, style, m_comma_style, m_space_type);
+    set_table (m_romaji_half_symbol, m_romaji_half_number,
+               m_typing_method, style, m_comma_style, m_space_type);
 }
 
 PeriodStyle
-Preedit::get_period_style (void)
+AnthyPreedit::get_period_style (void)
 {
     return m_period_style;
 }
 
 void
-Preedit::set_comma_style (CommaStyle style)
+AnthyPreedit::set_comma_style (CommaStyle style)
 {
-    set_table (m_typing_method, m_period_style, style, m_space_type);
+    set_table (m_romaji_half_symbol, m_romaji_half_number,
+               m_typing_method, m_period_style, style, m_space_type);
 }
 
 CommaStyle
-Preedit::get_comma_style (void)
+AnthyPreedit::get_comma_style (void)
 {
     return m_comma_style;
 }
 
 void
-Preedit::set_space_type (SpaceType type)
+AnthyPreedit::set_space_type (SpaceType type)
 {
-    set_table (m_typing_method, m_period_style, m_comma_style, type);
+    set_table (m_romaji_half_symbol, m_romaji_half_number,
+               m_typing_method, m_period_style, m_comma_style, type);
 }
 
 SpaceType
-Preedit::get_space_type (void)
+AnthyPreedit::get_space_type (void)
 {
     return m_space_type;
 }
 
 void
-Preedit::set_auto_convert (bool autoconv)
+AnthyPreedit::set_ten_key_type (TenKeyType type)
+{
+    m_ten_key_type = type;
+}
+
+TenKeyType
+AnthyPreedit::get_ten_key_type (void)
+{
+    return m_ten_key_type;
+}
+
+void
+AnthyPreedit::set_auto_convert (bool autoconv)
 {
     m_auto_convert = autoconv;
 }
 
 bool
-Preedit::get_auto_convert (void)
+AnthyPreedit::get_auto_convert (void)
 {
     return m_auto_convert;
 }
 
 void
-Preedit::set_table (TypingMethod method,
-                    PeriodStyle period,
-                    CommaStyle comma,
-                    SpaceType space)
+AnthyPreedit::set_table (bool romaji_half_symbol,
+                         bool romaji_half_number,
+                         TypingMethod method,
+                         PeriodStyle period,
+                         CommaStyle comma,
+                         SpaceType space)
 {
-    ConvRule *period_rule = get_period_rule (method, period);
-    ConvRule *comma_rule  = get_comma_rule  (method, comma);
-
     switch (method) {
     case METHOD_KANA:
-        m_key2kana.set_table (ja_kana_table);
+        m_key2kana.set_table (scim_anthy_kana_typing_rule);
         break;
     case METHOD_ROMAKANA:
     default:
-        m_key2kana.set_table (ja_romakana_table);
+        m_key2kana.set_table (scim_anthy_romakana_typing_rule);
+
+        if (romaji_half_symbol)
+            m_key2kana.append_table (scim_anthy_romakana_symbol_rule);
+        else
+            m_key2kana.append_table (scim_anthy_romakana_wide_symbol_rule);
+
+        if (romaji_half_number)
+            m_key2kana.append_table (scim_anthy_romakana_number_rule);
+        else
+            m_key2kana.append_table (scim_anthy_romakana_wide_number_rule);
+
         break;
     };
 
+    ConvRule *period_rule = get_period_rule (method, period);
     if (period_rule)
         m_key2kana.append_table (period_rule);
+
+    ConvRule *comma_rule  = get_comma_rule  (method, comma);
     if (comma_rule)
         m_key2kana.append_table (comma_rule);
 
     switch (space) {
     case SPACE_NORMAL:
-        m_key2kana.append_table (space_rule);
+        m_key2kana.append_table (scim_anthy_space_rule);
         break;
     case SPACE_WIDE:
     default:
-        m_key2kana.append_table (wide_space_rule);
+        m_key2kana.append_table (scim_anthy_wide_space_rule);
         break;
     };
 
-    m_typing_method = method;
-    m_period_style = period;
-    m_comma_style = comma;
-    m_space_type = space;
+    m_romaji_half_symbol = romaji_half_symbol;
+    m_romaji_half_number = romaji_half_number;
+    m_typing_method      = method;
+    m_period_style       = period;
+    m_comma_style        = comma;
+    m_space_type         = space;
 }
 
 bool
-Preedit::is_comma_or_period (const String & str)
+AnthyPreedit::is_comma_or_period (const String & str)
 {
     ConvRule *period_rule = get_period_rule (m_typing_method, m_period_style);
     ConvRule *comma_rule  = get_comma_rule  (m_typing_method, m_comma_style);
@@ -1176,9 +1315,9 @@ convert_string_to_wide (const String & str, WideString & wide, SpaceType space)
         char cc[2]; cc[0] = c; cc[1] = '\0';
         bool found = false;
 
-        for (unsigned int j = 0; ja_wide_table[j].code; j++) {
-            if (ja_wide_table[j].code && *ja_wide_table[j].code == c) {
-                wide += utf8_mbstowcs (ja_wide_table[j].wide);
+        for (unsigned int j = 0; scim_anthy_wide_table[j].code; j++) {
+            if (scim_anthy_wide_table[j].code && *scim_anthy_wide_table[j].code == c) {
+                wide += utf8_mbstowcs (scim_anthy_wide_table[j].wide);
                 found = true;
                 break;
             }
@@ -1205,13 +1344,13 @@ convert_hiragana_to_katakana (const WideString & hira, WideString & kata,
         WideString tmpwide;
         bool found = false;
 
-        for (unsigned int j = 0; ja_hiragana_katakana_table[j].hiragana; j++) {
-            tmpwide = utf8_mbstowcs (ja_hiragana_katakana_table[j].hiragana);
+        for (unsigned int j = 0; scim_anthy_hiragana_katakana_table[j].hiragana; j++) {
+            tmpwide = utf8_mbstowcs (scim_anthy_hiragana_katakana_table[j].hiragana);
             if (hira.substr(i, 1) == tmpwide) {
                 if (half)
-                    kata += utf8_mbstowcs (ja_hiragana_katakana_table[j].half_katakana);
+                    kata += utf8_mbstowcs (scim_anthy_hiragana_katakana_table[j].half_katakana);
                 else
-                    kata += utf8_mbstowcs (ja_hiragana_katakana_table[j].katakana);
+                    kata += utf8_mbstowcs (scim_anthy_hiragana_katakana_table[j].katakana);
                 found = true;
                 break;
             }
@@ -1229,24 +1368,24 @@ get_period_rule (TypingMethod method, PeriodStyle period)
     case METHOD_KANA:
         switch (period) {
         case PERIOD_WIDE_LATIN:
-            return kana_wide_latin_period_rule;
+            return scim_anthy_kana_wide_latin_period_rule;
         case PERIOD_LATIN:
-            return kana_latin_period_rule;
+            return scim_anthy_kana_latin_period_rule;
         case PERIOD_JAPANESE:
         default:
-            return kana_ja_period_rule;
+            return scim_anthy_kana_ja_period_rule;
         };
         break;
     case METHOD_ROMAKANA:
     default:
         switch (period) {
         case PERIOD_WIDE_LATIN:
-            return romakana_wide_latin_period_rule;
+            return scim_anthy_romakana_wide_latin_period_rule;
         case PERIOD_LATIN:
-            return romakana_latin_period_rule;
+            return scim_anthy_romakana_latin_period_rule;
         case PERIOD_JAPANESE:
         default:
-            return romakana_ja_period_rule;
+            return scim_anthy_romakana_ja_period_rule;
         };
         break;
     };
@@ -1261,24 +1400,24 @@ get_comma_rule (TypingMethod method, CommaStyle period)
     case METHOD_KANA:
         switch (period) {
         case PERIOD_WIDE_LATIN:
-            return kana_wide_latin_comma_rule;
+            return scim_anthy_kana_wide_latin_comma_rule;
         case PERIOD_LATIN:
-            return kana_latin_comma_rule;
+            return scim_anthy_kana_latin_comma_rule;
         case PERIOD_JAPANESE:
         default:
-            return kana_ja_comma_rule;
+            return scim_anthy_kana_ja_comma_rule;
         };
         break;
     case METHOD_ROMAKANA:
     default:
         switch (period) {
         case PERIOD_WIDE_LATIN:
-            return romakana_wide_latin_comma_rule;
+            return scim_anthy_romakana_wide_latin_comma_rule;
         case PERIOD_LATIN:
-            return romakana_latin_comma_rule;
+            return scim_anthy_romakana_latin_comma_rule;
         case PERIOD_JAPANESE:
         default:
-            return romakana_ja_comma_rule;
+            return scim_anthy_romakana_ja_comma_rule;
         };
         break;
     };
