@@ -70,15 +70,21 @@ typedef enum {
     SPACE_WIDE,
 } SpaceType;
 
+typedef enum {
+    TEN_KEY_HALF,
+    TEN_KEY_WIDE,
+    TEN_KEY_FOLLOW_MODE,
+} TenKeyType;
+
 typedef enum {
     PREEDIT_CURRENT,
     PREEDIT_RAW_KEY,
     PREEDIT_NO_CONVERSION,
     PREEDIT_NO_CONVERSION_HIRAGANA,
     PREEDIT_CONVERSION,
-} PreeditStringType;
+} AnthyPreeditStringType;
 
-class PreeditChar
+class AnthyPreeditChar
 {
 public:
     String     key;
@@ -86,8 +92,8 @@ public:
     bool       pending;
 
 public:
-    PreeditChar (void);
-    virtual ~PreeditChar ();
+    AnthyPreeditChar (void);
+    virtual ~AnthyPreeditChar ();
 
 #if 0
     void split    (void);
@@ -96,22 +102,23 @@ public:
 #endif
 };
 
-class Preedit
+class AnthyPreedit
 {
 public:
-    Preedit (void);
-    virtual ~Preedit ();
+    AnthyPreedit (void);
+    virtual ~AnthyPreedit ();
 
     // getting status
-    virtual unsigned int  get_length             (PreeditStringType type = PREEDIT_CURRENT);
-    virtual WideString    get_string             (PreeditStringType type = PREEDIT_CURRENT);
-    virtual AttributeList get_attribute_list     (PreeditStringType type = PREEDIT_CURRENT);
+    virtual unsigned int  get_length             (AnthyPreeditStringType type = PREEDIT_CURRENT);
+    virtual WideString    get_string             (AnthyPreeditStringType type = PREEDIT_CURRENT);
+    virtual AttributeList get_attribute_list     (AnthyPreeditStringType type = PREEDIT_CURRENT);
 
     virtual bool          is_preediting          (void);
     virtual bool          is_converting          (void);
     virtual bool          is_kana_converting     (void);
 
     // manipulating the preedit string
+    virtual bool          can_process            (const KeyEvent & key);
     // return true if commiting is needed.
     virtual bool          append                 (const KeyEvent & key);
     virtual void          erase                  (bool backward = true);
@@ -120,7 +127,8 @@ public:
     // manipulating the conversion string
     virtual void          convert                (CandidateType type = CANDIDATE_NORMAL);
     virtual void          revert                 (void);
-    virtual void          commit                 (int segment_id = -1);
+    virtual void          commit                 (int  segment_id = -1,
+                                                  bool lean       = true);
 
     // segments of the converted sentence
     virtual int           get_nr_segments        (void);
@@ -147,6 +155,10 @@ public:
     virtual void          clear                  (void);
 
     // preference
+    virtual void          set_symbol_width       (bool half);
+    virtual bool          symbol_is_half_width   (void);
+    virtual void          set_number_width       (bool half);
+    virtual bool          number_is_half_width   (void);
     virtual void          set_input_mode         (InputMode mode);
     virtual InputMode     get_input_mode         (void);
     virtual void          set_typing_method      (TypingMethod method);
@@ -157,6 +169,8 @@ public:
     virtual CommaStyle    get_comma_style        (void);
     virtual void          set_space_type         (SpaceType type);
     virtual SpaceType     get_space_type         (void);
+    virtual void          set_ten_key_type       (TenKeyType type);
+    virtual TenKeyType    get_ten_key_type       (void);
     virtual void          set_auto_convert       (bool autoconv);
     virtual bool          get_auto_convert       (void);
 
@@ -173,7 +187,9 @@ private:
                                                   unsigned int end,
                                                   CandidateType type);
     void          reset_pending                  (void);
-    void          set_table                      (TypingMethod method,
+    void          set_table                      (bool romaji_half_symbol,
+                                                  bool romaji_half_number,
+                                                  TypingMethod method,
                                                   PeriodStyle  period,
                                                   CommaStyle   comma,
                                                   SpaceType    space);
@@ -186,15 +202,18 @@ private:
     anthy_context_t   m_anthy_context;
 
     // mode flags
+    bool              m_romaji_half_symbol;
+    bool              m_romaji_half_number;
     InputMode         m_input_mode;
     TypingMethod      m_typing_method;
     PeriodStyle       m_period_style;
     CommaStyle        m_comma_style;
     SpaceType         m_space_type;
+    TenKeyType        m_ten_key_type;
     bool              m_auto_convert;
 
     // raw key code & preedit string
-    std::vector<PreeditChar> m_char_list;     // whole preedit characters includes commited one.
+    std::vector<AnthyPreeditChar> m_char_list;// whole preedit characters includes commited one.
                                               // start position of non-commited character is
                                               // pointed by m_start_segment_pos.
     unsigned int             m_start_char;    // to skip already commited characters.
